@@ -21,5 +21,8 @@ class PreRunEventData(BaseModel):
     imagesfile: Optional[str]
     model_name: str
     base_model_id: str
+    include_data: Optional[str]
+    exclude_classes: Optional[List[str]]
+    base_dataset_id: str
 
     root_validator(check_images_or_imagefile_has_data)
